@@ -717,6 +717,17 @@ GtkWidget *pidgin_make_mini_dialog(PurpleConnection *handle,
 	const char* stock_id, const char *primary, const char *secondary,
 	void *user_data, ...) G_GNUC_NULL_TERMINATED;
 
+/**
+ * Does exactly what pidgin_make_mini_dialog() does, except you can specify
+ * a custom icon for the dialog.
+ */
+GtkWidget *pidgin_make_mini_dialog_with_custom_icon(PurpleConnection *gc,
+	GdkPixbuf *custom_icon,
+	const char *primary,
+	const char *secondary,
+	void *user_data,
+	...) G_GNUC_NULL_TERMINATED;
+
 /**
  * This is a callback function to be used for Ctrl+F searching in treeviews.
  * Sample Use:
@@ -842,7 +853,7 @@ GdkPixbuf *pidgin_pixbuf_from_imgstore(PurpleStoredImage *image);
  * @width             Desired widget width, or -1 for default
  * @height            Desired widget height, or -1 for default
  *
- * @since 2.7.0
+ * @since 2.8.0
  */
 GtkWidget *pidgin_make_scrollable(GtkWidget *child, GtkPolicyType hscrollbar_policy, GtkPolicyType vscrollbar_policy, GtkShadowType shadow_type, int width, int height);
 
